==> orgmaker-3-3.0.7.tar.gz: orgmaker-3-3.0.7/source/OrgData.h <==
//ҏWp\///////////////
typedef struct{//Rs[\
	char track1;//̃gbN
	long x1_1;//
	long x1_2;//܂ł
	char track2;//̃gbN
	long x2;//
	long num;//
}NOTECOPY;

typedef struct{//gX|[gp|bg
	char track;//̃gbN
	long x1;//
	long x2;//܂ł
	unsigned char a;//ꂾ 
	unsigned char mode;//iЂj
}PARCHANGE;

//Xg\
typedef struct NOTELIST{
	NOTELIST *from;//ÕAhX
	NOTELIST *to;//̃AhX
	long x;//ʒu
	unsigned char length;//̒
	unsigned char y;//̍
	unsigned char volume;//H[
	unsigned char pan;//p
}NOTELIST;
//gbNf[^W
typedef struct{
	unsigned short freq;//+g(1000Default)
//	unsigned short note_num;//̐
	unsigned char wave_no;//g`No
	char pipi;
	NOTELIST *note_p;//NoteDatä̐擪AhX
	NOTELIST *note_list;//Xg̐擪AhX1
}TRACKDATA;
//ȒPʂŎŗL̏
typedef struct MUSICINFO{
	unsigned short wait;
	unsigned char line;//Number of lines in one bar
	unsigned char dot;//Number of dots per night
	unsigned short alloc_note;//number of reserved notes
	long repeat_x;//s[g
	long end_x;//Ȃ̏I(s[gɖ߂)
	TRACKDATA tdata[16];
}MUSICINFO;
//CNXB̃AvP[V̒SBiNXĂ߂Ďgj
typedef struct OrgData{
	OrgData();//RXgN^
	~OrgData();//fXgN^
	private:
		MUSICINFO info;
	public:
		//unsigned char *noteon;
		BOOL SetNote_afterSetLength(long x);
		BOOL SetNote_onlyLength(long x, long Length);

		void RedrawSelectArea(void);
		//AhDp
		int ReplaceFromRedoData();
		int ReplaceFromUndoData();
		void ClearUndoData();
		int SetUndoData();
		int ResetLastUndo(void); //Ō̃AhD͂ȂƂɁIiNbNƂj
		MUSICINFO ud_tdata[32]; //Ƃ肠AAhD32
		NOTELIST  ud_note[32][16][4096];
		bool UndoEnable;
		bool RedoEnable;
		int CurrentUndoCursor; //̔ԍɏ
		int MinimumUndoCursor; //̔ԍ܂łȂ炳̂ڂ
		int MaximumUndoCursor; //̔ԍ܂łȂ蒼ihD\j

		char track;
		char mute[MAXTRACK];
		unsigned char def_pan[MAXTRACK];
		unsigned char def_volume[MAXTRACK];
		void InitOrgData(void);
		void GetMusicInfo(MUSICINFO *mi);//ȏ擾
		//ȏݒBflag͐ݒACew
		BOOL SetMusicInfo(MUSICINFO *mi,unsigned long flag);
		BOOL NoteAlloc(unsigned short note_num);//w̐NoteDatä̗m
		void ReleaseNote(void);//NoteDataJ
		NOTELIST *SearchNote(NOTELIST *np);//gpNOTĚ
		void OrgData::TouchKeyboard(unsigned char y);//ՂɐG
		void OrgData::StopKeyboard(unsigned char y);//ՂɐG
		BOOL SetNote(long x,unsigned char y, int DragMode = 0);//zu
		BOOL CutNote(long x,unsigned char y);//̃Jbg
		BOOL SetPan(long x,unsigned char y);//pzu
		BOOL SetPan2(long x,unsigned char y);//pzu
		BOOL CutPan(long x,unsigned char y);//p̃Jbg
		BOOL SetVolume(long x,unsigned char y);//{[zu
		BOOL SetVolume2(long x,unsigned char y,long fade); //tF[hAEg	// 2010.08.17 A
		BOOL CutVolume(long x,unsigned char y);//{[̃Jbg
		BOOL EnlargeAllNotes(int Power);//[V]Power{ɈL΂
		BOOL ShortenAllNotes(int Power);//[V]1/Power{ɏk߂

		void SortNotes(void);	//̐
		int SearchNote(long x,unsigned char y, int YuusenTrack);//ǂ̃gbNɂ鉹Ȟ
		int SearchNoteB(long x,unsigned char y, long *lStartx, long *lLastx, int YuusenTrack);//ǂ̃gbNɂ鉹Ȟ 2014.05.02
		int SearchNoteC(long x,unsigned char y, long xWidth, long xMod);//k\̌B
		

		void GetNoteUsed(long *use,long *left,char track);//cʓ
		//ȉ͕\
		void PutNotes(int TPCY, bool vol);
		void PutNotes2(int TPCY, bool vol);
		void PutMusic(void);
		void PutNumber(void);
		void PutRepeat(void);
		bool PutBackGround(void);	//wiĕ`
		void PutSelectArea(void);
		//ȉ͍Đ
		void PlayData(void);
		void SetPlayPointer(long x);//Đ|C^[ẅʒuɐݒ
		void GetPlayPos(long *playpos);
		//ȉ̓t@C֌W
		unsigned short GetNoteNumber(char track,NOTECOPY *nc);
		BOOL OrgData::SaveMusicData(void);
		BOOL OrgData::LoadMusicData(void);
		int FileCheckBeforeLoad(char *checkfile); //t@C[h\ł0ُł1ԂBް[h͂ȂB 2014.05.22
		//ȉ͕ҏW֌W
		BOOL DelateNoteData(PARCHANGE *pc);
		BOOL CopyNoteData(NOTECOPY *nc);
		BOOL ChangePanData(PARCHANGE *pc);
		BOOL ChangeTransData(PARCHANGE *pc);
		BOOL ChangeVolumeData(PARCHANGE *pc);
		BOOL CheckNoteTail(char track);

		BOOL EnsureEmptyArea(PARCHANGE *pc, int Function); //[V]󔒂𖄂߂ 2014.05.01
		BOOL SwapTrack(NOTECOPY *pc); //[V]gbNւ 2014.05.10
		BOOL ExportMIDIData(char *strMidiFileName, int iRepeat); //MIDI߰,JԂ 2014.05.11



	bool CopyNoteDataToCB(NOTECOPY *nc, int iTrack, int iFullTrack);
}ORGDATA;
extern ORGDATA org_data;

==> orgmaker-3-3.0.8.tar.gz: orgmaker-3-3.0.8/source/OrgData.h <==
//ҏWp\///////////////
typedef struct{//Rs[\
	char track1;//̃gbN
	long x1_1;//
	long x1_2;//܂ł
	char track2;//̃gbN
	long x2;//
	long num;//
}NOTECOPY;

typedef struct{//gX|[gp|bg
	char track;//̃gbN
	long x1;//
	long x2;//܂ł
	unsigned char a;//ꂾ 
	unsigned char mode;//iЂj
}PARCHANGE;

//Xg\
typedef struct NOTELIST{
	NOTELIST *from;//ÕAhX
	NOTELIST *to;//̃AhX
	long x;//ʒu
	unsigned char length;//̒
	unsigned char y;//̍
	unsigned char volume;//H[
	unsigned char pan;//p
}NOTELIST;
//gbNf[^W
typedef struct{
	unsigned short freq;//+g(1000Default)
//	unsigned short note_num;//̐
	unsigned char wave_no;//g`No
	char pipi;
	NOTELIST *note_p;//NoteDatä̐擪AhX
	NOTELIST *note_list;//Xg̐擪AhX1
}TRACKDATA;
//ȒPʂŎŗL̏
typedef struct MUSICINFO{
	unsigned short wait;
	unsigned char line;//Number of lines in one bar
	unsigned char dot;//Number of dots per night
	unsigned short alloc_note;//number of reserved notes
	long repeat_x;//s[g
	long end_x;//Ȃ̏I(s[gɖ߂)
	TRACKDATA tdata[16];
}MUSICINFO;
//CNXB̃AvP[V̒SBiNXĂ߂Ďgj
typedef struct OrgData{
	OrgData();//RXgN^
	~OrgData();//fXgN^
	private:
		MUSICINFO info;
	public:
		//unsigned char *noteon;
		BOOL SetNote_afterSetLength(long x);
		BOOL SetNote_onlyLength(long x, long Length);

		void RedrawSelectArea(void);
		//AhDp
		int ReplaceFromRedoData();
		int ReplaceFromUndoData();
		void ClearUndoData();
		int SetUndoData();
		int ResetLastUndo(void); //Ō̃AhD͂ȂƂɁIiNbNƂj
		MUSICINFO ud_tdata[32]; //Ƃ肠AAhD32
		NOTELIST  ud_note[32][16][4096];
		bool UndoEnable;
		bool RedoEnable;
		int CurrentUndoCursor; //̔ԍɏ
		int MinimumUndoCursor; //̔ԍ܂łȂ炳̂ڂ
		int MaximumUndoCursor; //̔ԍ܂łȂ蒼ihD\j

		char track;
		char mute[MAXTRACK];
		unsigned char def_pan[MAXTRACK];
		unsigned char def_volume[MAXTRACK];
		void InitOrgData(void);
		void GetMusicInfo(MUSICINFO *mi, int mode = 0);//ȏ擾
		//ȏݒBflag͐ݒACew
		BOOL SetMusicInfo(MUSICINFO *mi,unsigned long flag);
		BOOL NoteAlloc(unsigned short note_num);//w̐NoteDatä̗m
		void ReleaseNote(void);//NoteDataJ
		NOTELIST *SearchNote(NOTELIST *np);//gpNOTĚ
		void OrgData::TouchKeyboard(unsigned char y);//ՂɐG
		void OrgData::StopKeyboard(unsigned char y);//ՂɐG
		BOOL SetNote(long x,unsigned char y, int DragMode = 0);//zu
		BOOL CutNote(long x,unsigned char y);//̃Jbg
		BOOL SetPan(long x,unsigned char y);//pzu
		BOOL SetPan2(long x,unsigned char y);//pzu
		BOOL CutPan(long x,unsigned char y);//p̃Jbg
		BOOL SetVolume(long x,unsigned char y);//{[zu
		BOOL SetVolume2(long x,unsigned char y,long fade); //tF[hAEg	// 2010.08.17 A
		BOOL CutVolume(long x,unsigned char y);//{[̃Jbg
		BOOL EnlargeAllNotes(int Power);//[V]Power{ɈL΂
		BOOL ShortenAllNotes(int Power);//[V]1/Power{ɏk߂

		void SortNotes(void);	//̐
		int SearchNote(long x,unsigned char y, int YuusenTrack);//ǂ̃gbNɂ鉹Ȟ
		int SearchNoteB(long x,unsigned char y, long *lStartx, long *lLastx, int YuusenTrack);//ǂ̃gbNɂ鉹Ȟ 2014.05.02
		int SearchNoteC(long x,unsigned char y, long xWidth, long xMod);//k\̌B
		

		void GetNoteUsed(long *use,long *left,char track);//cʓ
		//ȉ͕\
		void PutNotes(int TPCY, bool vol);
		void PutNotes2(int TPCY, bool vol);
		void PutMusic(void);
		void PutNumber(void);
		void PutRepeat(void);
		bool PutBackGround(void);	//wiĕ`
		void PutSelectArea(void);
		//ȉ͍Đ
		void PlayData(void);
		void SetPlayPointer(long x);//Đ|C^[ẅʒuɐݒ
		void GetPlayPos(long *playpos);
		//ȉ̓t@C֌W
		unsigned short GetNoteNumber(char track,NOTECOPY *nc);
		BOOL OrgData::SaveMusicData(void);
		BOOL OrgData::LoadMusicData(void);
		int FileCheckBeforeLoad(char *checkfile); //t@C[h\ł0ُł1ԂBް[h͂ȂB 2014.05.22
		//ȉ͕ҏW֌W
		BOOL DelateNoteData(PARCHANGE *pc);
		BOOL CopyNoteData(NOTECOPY *nc);
		BOOL ChangePanData(PARCHANGE *pc);
		BOOL ChangeTransData(PARCHANGE *pc);
		BOOL ChangeVolumeData(PARCHANGE *pc);
		BOOL CheckNoteTail(char track);

		BOOL EnsureEmptyArea(PARCHANGE *pc, int Function); //[V]󔒂𖄂߂ 2014.05.01
		BOOL SwapTrack(NOTECOPY *pc); //[V]gbNւ 2014.05.10
		BOOL ExportMIDIData(char *strMidiFileName, int iRepeat); //MIDI߰,JԂ 2014.05.11

		unsigned short GetWait(void);

	bool CopyNoteDataToCB(NOTECOPY *nc, int iTrack, int iFullTrack);
}ORGDATA;
extern ORGDATA org_data;
